package com.fs.chat.service;

import java.util.List;
import com.fs.chat.domain.ChatUser;

/**
 * 客户Service接口
 *
 * @author fs
 * @date 2024-05-11
 */
public interface IChatUserService
{
    /**
     * 查询客户
     *
     * @param userId 客户主键
     * @return 客户
     */
    public ChatUser selectChatUserByUserId(Long userId);

    /**
     * 查询客户列表
     *
     * @param chatUser 客户
     * @return 客户集合
     */
    public List<ChatUser> selectChatUserList(ChatUser chatUser);

    /**
     * 新增客户
     *
     * @param chatUser 客户
     * @return 结果
     */
    public int insertChatUser(ChatUser chatUser);

    /**
     * 修改客户
     *
     * @param chatUser 客户
     * @return 结果
     */
    public int updateChatUser(ChatUser chatUser);

    /**
     * 批量删除客户
     *
     * @param userIds 需要删除的客户主键集合
     * @return 结果
     */
    public int deleteChatUserByUserIds(Long[] userIds);

    /**
     * 删除客户信息
     *
     * @param userId 客户主键
     * @return 结果
     */
    public int deleteChatUserByUserId(Long userId);

    ChatUser selectChatUserByExternalUserId(String external_userid);
}
